@@ -7,12 +7,11 @@ Disable this check by passing ``override=True``
 
 """
 
-EMAILME = """
-The ANSYS gRPC interface currently requires the closed source python
-module ``ansys.mapdl`` to open a connection to the gRPC server.
-Please contact Alex Kaszynski at alexander.kaszynski@ansys.com to
-request access to the code repository.
-"""
+class VersionError(ValueError):
+    """Raised when MAPDL is the wrong version"""
+
+    def __init__(self, msg='Invalid MAPDL version'):
+        ValueError.__init__(self, msg)
 
 class MapdlRuntimeError(RuntimeError):
     """Raised when MAPDL passes an error"""
@@ -36,10 +35,3 @@ class LockFileException(RuntimeError):
     """Error message when the lockfile has not been removed"""
     def __init__(self, msg=LOCKFILE_MSG):
         RuntimeError.__init__(self, msg)
-
-
-class PrivateModuleImportError(ImportError):
-    """Raised when attempting to import a closed source module"""
-
-    def __init__(self, msg=EMAILME):
-        ImportError.__init__(self, msg)
