@@ -19,7 +19,7 @@ from pyansys.geometry_commands import geometry_commands
 from pyansys.element_commands import element_commands
 from pyansys.errors import MapdlRuntimeError, MapdlInvalidRoutineError
 from pyansys.plotting import general_plotter
-
+from pyansys.launcher import get_ansys_path
 
 MATPLOTLIB_LOADED = True
 try:
@@ -335,11 +335,6 @@ class _MapdlCore(_MapdlCommands):
         """
         return self._mesh
 
-    # @property
-    # def _mesh(self):  # pragma: no cover
-    #     """Implemented by child class"""
-    #     raise NotImplementedError('Implemented by child class')
-
     @property
     @supress_logging
     def _mesh(self):
@@ -464,22 +459,24 @@ class _MapdlCore(_MapdlCommands):
         if os.path.isfile(tmp_database):
             os.remove(tmp_database)
 
-        # get the state, close, and finish
+        # cache result file, version, and routine before closing
+        resultfile = self._result_file
+        version = self.version
         prior_processor = self.parameters.routine
+
+        # get the close, and finish
         self.finish()
         self.save(tmp_database)
-        # self.exit(close_log=False)
         self.exit()
 
         # copy result file to temp directory
         if include_result:
-            resultfile = os.path.join(self.path, '%s.rst' % self.jobname)
             if os.path.isfile(resultfile):
                 tmp_resultfile = os.path.join(save_path, '%s.rst' % name)
                 copyfile(resultfile, tmp_resultfile)
 
         # write temporary input file
-        start_file = os.path.join(save_path, 'start%s.ans' % self.version)
+        start_file = os.path.join(save_path, 'start%s.ans' % version)
         with open(start_file, 'w') as f:
             f.write('RESUME\n')
 
@@ -491,22 +488,25 @@ class _MapdlCore(_MapdlCommands):
         # issue system command to run ansys in GUI mode
         cwd = os.getcwd()
         os.chdir(save_path)
-        os.system('cd "%s" && "%s" -g -j %s' % (save_path,
-                                                self._start_parm['exec_file'],
-                                                name))
+        exec_file = self._start_parm.get('exec_file',
+                                         get_ansys_path(allow_input=False))
+        os.system('cd "%s" && "%s" -g -j %s' % (save_path, exec_file, name))
         os.chdir(cwd)
 
         # must remove the start file when finished
         os.remove(start_file)
         os.remove(other_start_file)
 
-        # reload database when finished
-        # self._launch()  # TODO
+        # reattach to a new session and reload database
+        self._launch(self._start_parm)
         self.resume(tmp_database)
         if prior_processor is not None:
             if 'BEGIN' not in prior_processor:
                 self.run('/%s' % prior_processor)
 
+    def _launch(self, *args, **kwargs):  # pragma: no cover
+        raise NotImplementedError('Implemented by child class')
+
     def _close_apdl_log(self):
         """Closes the APDL log"""
         if self._apdl_log is not None:
@@ -1052,6 +1052,20 @@ class _MapdlCore(_MapdlCommands):
         if not self._local:
             raise RuntimeError('Binary interface only available when result is local.')
 
+        result_path = self._result_file
+        if not os.path.isfile(result_path):
+            raise FileNotFoundError('No results found at %s' % result_path)
+        return pyansys.read_binary(result_path)
+
+    @property
+    def _result_file(self):
+        """Path of the result file
+
+        Notes
+        -----
+        There may be multiple result files at this location (if not
+        combining results)
+        """
         try:
             result_path = self.inquire('RSTFILE')
         except RuntimeError:
@@ -1061,12 +1075,7 @@ class _MapdlCore(_MapdlCommands):
             result_path = os.path.join(self.path, '%s.rst' % self._jobname)
         elif not os.path.dirname(result_path):
             result_path = os.path.join(self.path, '%s.rst' % result_path)
-
-        # there may be multiple result files at this location (if not
-        # combining results)
-        if not os.path.isfile(result_path):
-            raise FileNotFoundError('No results found at %s' % result_path)
-        return pyansys.read_binary(result_path)
+        return result_path
 
     def _get(self, *args, **kwargs):
         """Simply use the default get method"""
@@ -1250,14 +1259,14 @@ class _MapdlCore(_MapdlCommands):
         --------
         Retreive the number of nodes
 
-        >>> value = ansys.get('val', 'node', '', 'count')
+        >>> value = mapdl.get('val', 'node', '', 'count')
         >>> value
         3003
 
         Retreive the number of nodes using keywords.  Note that the
         parameter name is optional.
 
-        >>> value = ansys.get(entity='node', item1='count')
+        >>> value = mapdl.get(entity='node', item1='count')
         >>> value
         3003
 
@@ -1337,7 +1346,7 @@ class _MapdlCore(_MapdlCommands):
 
         Returns
         -------
-        float
+        value : float
             Value returned by inline function.
 
         Examples
@@ -1526,6 +1535,11 @@ class _MapdlCore(_MapdlCommands):
             Calculate element results, reaction forces, energies, and
             the nodal degree of freedom solution.  Default ``False``.
 
+        Returns
+        -------
+        response : str
+            Output from MAPDL SOLVE command. 
+
         Examples
         --------
         Modal analysis using default parameters for the first 6 modes
@@ -1564,10 +1578,11 @@ class _MapdlCore(_MapdlCommands):
         if elcalc:
             self.mxpand(elcalc='YES')
 
-        self.solve()
+        out = self.solve()
         self.finish()
+        return out
 
-    def run(self, command, write_to_log=True):
+    def run(self, command, write_to_log=True, **kwargs):
         """Runs APDL command
 
         Parameters
@@ -1580,6 +1595,9 @@ class _MapdlCore(_MapdlCommands):
             False, will not write command to log, even if APDL
             command logging is enabled.
 
+        kwargs : Optional keyword arguments
+            These keyword arguments are interface specific.
+
         Returns
         -------
         command_output : str
@@ -1624,7 +1642,7 @@ class _MapdlCore(_MapdlCommands):
             function = self._redirected_commands[command[:4]]
             return function(command)
 
-        text = self._run(command)
+        text = self._run(command, **kwargs)
         if text:
             self._response = text.strip()
         else:
@@ -1767,6 +1785,15 @@ class _MapdlCore(_MapdlCommands):
               ...
               314., 315., 316., 317., 318., 319., 320., 321.])
 
+        List the displacement in the X direction for the first result
+
+        >>> mapdl.post1()
+        >>> mapdl.set(1, 1)
+        >>> disp_x = mapdl.get_array('NODE', item1='U', it1num='X')
+        array([ 0.01605306, -0.01605306,  0.00178402, -0.01605306,
+               ...
+               -0.00178402, -0.01234851,  0.01234851, -0.01234851])
+
         Notes
         -----
         Please reference your ANSYS help manual *VGET command tables
@@ -1838,11 +1865,6 @@ class _MapdlCore(_MapdlCommands):
         filenames.sort()
         return filenames[-1]
 
-    @property
-    def math(self):  # pragma: no cover
-        """Return mapdl.math instance"""
-        raise NotImplementedError("Requires gRPC interface")
-
     def _set_log_level(self, level):
         """alias for set_log_level"""
         self.set_log_level(level)
